@@ -21,6 +21,7 @@
 #include <exception> // for std::exception
 #include <iostream>  // for std::cout, std::cerr
 #include <string>    // for std::string
+#include <utility>
 
 // Allow any format of input files (XML, PBF, ...)
 #include <osmium/io/any_input.hpp>
@@ -28,6 +29,8 @@
 // Allow any format of output files (XML, PBF, ...)
 #include <osmium/io/any_output.hpp>
 
+namespace {
+
 void print_help() {
     std::cout << "osmium_convert [OPTIONS] [INFILE [OUTFILE]]\n\n" \
               << "If INFILE or OUTFILE is not given stdin/stdout is assumed.\n" \
@@ -54,6 +57,8 @@ void print_usage(const char* prgname) {
     std::cerr << "Usage: " << prgname << " [OPTIONS] [INFILE [OUTFILE]]\n";
 }
 
+} // anonymous namespace
+
 int main(int argc, char* argv[]) {
     if (argc == 1) {
         print_usage(argv[0]);
