@@ -13,6 +13,7 @@
 #include <gdalcpp.hpp>
 
 #include <cstring>
+#include <exception>
 #include <fstream>
 #include <iostream>
 #include <map>
@@ -31,6 +32,8 @@ struct less_charptr {
 
 using tagmap_type = std::map<const char*, const char*, less_charptr>;
 
+namespace {
+
 tagmap_type create_map(const osmium::TagList& taglist) {
     tagmap_type map;
 
@@ -41,6 +44,8 @@ tagmap_type create_map(const osmium::TagList& taglist) {
     return map;
 }
 
+} // anonymous namespace
+
 class TestHandler : public osmium::handler::Handler {
 
     gdalcpp::Layer m_layer_point;
