@@ -6,6 +6,8 @@
 #include <osmium/relations/relations_database.hpp>
 #include <osmium/storage/item_stash.hpp>
 
+namespace {
+
 osmium::memory::Buffer fill_buffer() {
     using namespace osmium::builder::attr; // NOLINT(google-build-using-namespace)
     osmium::memory::Buffer buffer{1024UL * 1024UL, osmium::memory::Buffer::auto_grow::yes};
@@ -38,6 +40,8 @@ osmium::memory::Buffer fill_buffer() {
     return buffer;
 }
 
+} // anonymous namespace
+
 TEST_CASE("Fill member database") {
     const auto buffer = fill_buffer();
 
