@@ -46,22 +46,22 @@ TEST_CASE("number of threads in pool") {
 }
 
 TEST_CASE("if zero number of threads requested, threads configured") {
-    osmium::thread::Pool pool{0};
+    const osmium::thread::Pool pool{0};
     REQUIRE(pool.num_threads() > 0);
 }
 
 TEST_CASE("if any negative number of threads requested, threads configured") {
-    osmium::thread::Pool pool{-1};
+    const osmium::thread::Pool pool{-1};
     REQUIRE(pool.num_threads() > 0);
 }
 
 TEST_CASE("if outlier negative number of threads requested, threads configured") {
-    osmium::thread::Pool pool{-100};
+    const osmium::thread::Pool pool{-100};
     REQUIRE(pool.num_threads() > 0);
 }
 
 TEST_CASE("if outlier positive number of threads requested, threads configured") {
-    osmium::thread::Pool pool{1000};
+    const osmium::thread::Pool pool{1000};
     REQUIRE(pool.num_threads() > 0);
 }
 
@@ -83,12 +83,12 @@ TEST_CASE("can throw from job in default thread pool") {
 }
 
 TEST_CASE("can get access to user provided thread pool") {
-    osmium::thread::Pool pool{7};
+    const osmium::thread::Pool pool{7};
     REQUIRE(pool.queue_empty());
 }
 
 TEST_CASE("can access user-provided number of threads from pool") {
-    osmium::thread::Pool pool{7};
+    const osmium::thread::Pool pool{7};
     REQUIRE(pool.num_threads() == 7);
 }
 
