@@ -2,6 +2,9 @@
 
 #include <osmium/util/string.hpp>
 
+#include <string>
+#include <vector>
+
 TEST_CASE("split_string string") {
     const std::string str{"foo,baramba,baz"};
     const std::vector<std::string> result = {"foo", "baramba", "baz"};
@@ -67,7 +70,7 @@ TEST_CASE("split_string sep") {
 }
 
 TEST_CASE("split_string empty string") {
-    const std::string str{""};
+    const std::string str{};
     const std::vector<std::string> result;
 
     REQUIRE(result == osmium::split_string(str, ','));
