@@ -2,16 +2,13 @@
 
 #include <osmium/util/string_matcher.hpp>
 
+#include <regex>
 #include <sstream>
 #include <string>
 #include <type_traits>
 #include <utility>
 #include <vector>
 
-#ifdef OSMIUM_WITH_REGEX
-#include <regex>
-#endif
-
 static_assert(std::is_default_constructible<osmium::StringMatcher>::value, "StringMatcher should be default constructible");
 static_assert(std::is_copy_constructible<osmium::StringMatcher>::value, "StringMatcher should be copy constructible");
 static_assert(std::is_move_constructible<osmium::StringMatcher>::value, "StringMatcher should be move constructible");
@@ -90,7 +87,6 @@ TEST_CASE("String matcher: empty prefix") {
     REQUIRE(m.match(""));
 }
 
-#ifdef OSMIUM_WITH_REGEX
 TEST_CASE("String matcher: regex prefix") {
     const osmium::StringMatcher::regex m{std::regex{"^foo", std::regex::optimize}};
     REQUIRE(m.match("foo"));
@@ -107,7 +103,6 @@ TEST_CASE("String matcher: regex substr") {
     REQUIRE(m.match("xfoox"));
     REQUIRE_FALSE(m.match(""));
 }
-#endif
 
 TEST_CASE("String matcher: list") {
     const osmium::StringMatcher::list m{{"foo", "bar"}};
@@ -157,14 +152,12 @@ TEST_CASE("Construct StringMatcher from string") {
     REQUIRE(print(m) == "equal[foo]");
 }
 
-#ifdef OSMIUM_WITH_REGEX
 TEST_CASE("Construct StringMatcher from regex") {
     const osmium::StringMatcher m{std::regex{"^foo"}};
     REQUIRE(m("foo"));
     REQUIRE_FALSE(m("bar"));
     REQUIRE(print(m) == "regex");
 }
-#endif
 
 TEST_CASE("Construct StringMatcher from list") {
     const std::vector<std::string> v{"foo", "xxx"};
